% SCRIPT to ILLUSTRATE UTILITY of the SIMULATION TOOL;
% -------------------------------------------------------------------------
% it makes the redesign of Phase III survival trial  reported by Adelstein 
% et al. (2003) assuming exponential outcomes, based on 5, 000 simulation runs.
% -------------------------------------------------------------------------

% initialization of simulation options
   rspdistr = 'Exponential';         % time-to-event distribution
        trt = 3;                     % number of treatments
        sbj = 295;                   % number of patients involved in the trial
       sbj0 = 30;                    % number of patients randomized with CRD
     cohort = 30;                    % number of patients in the cohort
        sim = 5000;                  % number of simulation
    designs = {'D-A-Optimal', ...
               'A-A-Optimal', ...
               'NP-1', ...
               'Balanced'};          % designs applied
    options = [18.2, 27.6, 19.9];    % Exponential distr. options
                                     % (th1 = 18.2, th2 = 27.6, th3 = 19.9)
          R = 94;                    % recruitment period time
          D = 106;                   % trial duration time
  isdelayed = [0 1];                 % responses are delayed
  
  clc                                % clear command window

  for d = 1:length(designs)
      design = designs{d};
      if strcmpi(design, 'NP-1')
          B = 0.1;
      else
          B = [];
      end
      for del = 1:2
       % setup simulated trial
         trial = trsetup(rspdistr, options, design, 'D-A-Optimal', [], R, D, B, [], ...
             trt, sbj, sbj0, cohort, 'DBCD', sim, [], isdelayed(del)); 
         if ~and(strcmpi(design, 'Balanced'), isdelayed(del) == 1)
           % simulate trial 
             tr = trsimulate(trial);
           % display results
             sep = '------------------------------------------------------------------------------------------------------\n';
             fprintf(sep);
             fprintf('|             Time-to-event distribution: %s%s |\n', rspdistr, blanks(47))
             fprintf('|     Time-to-event distribution options: th = (%4.2f, %4.2f, %4.2f)%s |\n', options, blanks(32))
             fprintf('|                                 Design: %s%s |\n', design, blanks(58-length(design)))
             fprintf('|                   Number of treatments: %i%s |\n', trt, blanks(57))
             fprintf('|                     Number of patients: %i%s |\n', sbj, blanks(55))
             fprintf('| Number of patients randomized with CRD: %i%s |\n', sbj0, blanks(56))
             fprintf('|           Number of patients in cohort: %i%s |\n', cohort, blanks(56))
             fprintf('|                  Number of simulations: %i%s |\n', sim, blanks(54))
             fprintf('|                     Recruitment period: %i%s |\n', R, blanks(56))
             fprintf('|                         Trial duration: %i%s |\n', D, blanks(55))
             fprintf('|     Delayed response (1 = YES, 0 = NO): %i%s |\n', isdelayed(del), blanks(57))
  
             fprintf(sep);
             fprintf('|    Characteristic    |       Theoretical     |        Average        |      Std. dev      | Median |\n' )
             fprintf(sep);
             fprintf('|  (rho1, rho2, rho3)  | (% 4.2f, % 4.2f, % 4.2f) | (% 4.2f, % 4.2f, % 4.2f) | (%4.2f, %4.2f, %4.2f) |        |\n', ...
                 tr.ta, mean(mean(tr.TRT), 3), std(mean(tr.TRT), [], 3));
             fprintf('|  ( th1,  th2,  th3)  | (%4.2f, %4.2f, %4.2f) | (%4.2f, %4.2f, %4.2f) | (%4.2f, %4.2f, %4.2f) |        |\n', ...
                 tr.opt, mean(tr.optmle(end, :, :), 3), std(tr.optmle(end, :, :), [], 3));
             fprintf('|                   TT |                       |                 %4.0f  |              %4.0f  |   %4.0f |\n', ...
                 mean(tr.TT), std(tr.TT), median(tr.TT));
             fprintf('|       D-A-efficiency |                 %4.2f  |                       |                    |  % 4.2f |\n', ...
                 tr.eff.th(1), median(tr.eff.sim(:, 1)));
             fprintf(sep)
             fprintf('\n')
         end
      end
  end