% SCRIPT to ILLUSTRATE UTILITY of the SIMULATION TOOL;
% -------------------------------------------------------------------------
% it makes the redesign of Phase III survival trial  reported by Adelstein 
% et al. (2003) assuming Weibull outcomes, based on 5, 000 simulation runs.
% -------------------------------------------------------------------------

% initialization of simulation options
   rspdistr = 'Weibull';             % time-to-event distribution
        trt = 3;                     % number of treatments
        sbj = 295;                   % number of patients involved in the trial
       sbj0 = 30;                    % number of patients randomized with CRD
     cohort = 30;                    % number of patients in the cohort
        sim = 5000;                  % number of simulation
    designs = {'D-Optimal', ...
               'WO-Euclid', ...
               'Ethical'};          % designs applied
    options = [2.90, 3.32, 2.99, 1]; % Exponential distr. options
                                     % (mu1 = 2.90, mu2 = 3.32, mu3 = 2.99)
                                     % b = 1
          R = 94;                    % recruitment period time
          D = 106;                   % trial duration time
  isdelayed = [0 1];                 % responses are delayed
     islong = 0;                     % 
  clc                                % clear command window

  for d = 1:length(designs)
      design = designs{d};
      if strcmpi(design, 'WO-Euclid')
          alpha = 0.5;
          alphastr = ' (alpha = 0.5)';
          nblanks = 44 - length(design);
      else
          alpha = [];
          alphastr = '';
          nblanks = 58 - length(design);
      end
      for del = 1:2
       % setup simulated trial
         trial = trsetup(rspdistr, options, design, 'all', [], R, D, [], [], ...
             trt, sbj, sbj0, cohort, 'DBCD', sim, alpha, isdelayed(del)); 
       % simulate trial 
         tr = trsimulate(trial);
       % display results
         sep = '------------------------------------------------------------------------------------------------------\n';
         fprintf(sep);
         fprintf('|             Time-to-event distribution: %s%s |\n', rspdistr, blanks(51))
         fprintf('|     Time-to-event distribution options: mu = (%4.2f, %4.2f, %4.2f), b = %4.2f%s |\n', options, blanks(25))
         fprintf('|                                 Design: %s%s%s |\n', design, alphastr, blanks(nblanks))
         fprintf('|                   Number of treatments: %i%s |\n', trt, blanks(57))
         fprintf('|                     Number of patients: %i%s |\n', sbj, blanks(55))
         fprintf('| Number of patients randomized with CRD: %i%s |\n', sbj0, blanks(56))
         fprintf('|           Number of patients in cohort: %i%s |\n', cohort, blanks(56))
         fprintf('|                  Number of simulations: %i%s |\n', sim, blanks(54))
         fprintf('|                     Recruitment period: %i%s |\n', R, blanks(56))
         fprintf('|                         Trial duration: %i%s |\n', D, blanks(55))
         fprintf('|     Delayed response (1 = YES, 0 = NO): %i%s |\n', isdelayed(del), blanks(57))
 
         fprintf(sep);
         fprintf('|    Characteristic    |       Theoretical     |        Average        |      Std. dev      | Median |\n' )
         fprintf(sep);
         fprintf('|  (rho1, rho2, rho3)  | (% 4.2f, % 4.2f, % 4.2f) | (% 4.2f, % 4.2f, % 4.2f) | (%4.2f, %4.2f, %4.2f) |        |\n', ...
             tr.ta, mean(mean(tr.TRT), 3), std(mean(tr.TRT), [], 3));
         fprintf('|  ( mu1,  mu2,  mu3)  | (% 4.2f, % 4.2f, % 4.2f) | (% 4.2f, % 4.2f, % 4.2f) | (%4.2f, %4.2f, %4.2f) |        |\n', ...
             tr.opt(1:end-1), mean(tr.optmle(end, 1:end-1, :), 3), std(tr.optmle(end, 1:end-1, :), [], 3));
         fprintf('|                    b |                 %4.2f  |                 %4.2f  |              %4.2f  |        |\n', ...
             tr.opt(end), mean(tr.optmle(end, end, :), 3), std(tr.optmle(end, end, :), [], 3));
         fprintf('|                   TT |                       |                 %4.0f  |              %4.0f  |   %4.0f |\n', ...
             mean(tr.TT), std(tr.TT), median(tr.TT));
         fprintf('|       D-A-efficiency |                 %4.2f  |                       |                    |  % 4.2f |\n', ...
             tr.eff.DAth, median(tr.eff.DAsim));
         fprintf(sep)
         fprintf('\n')
      end
  end